def atomic_energy(element):
    energies = {
        "Ag": -0.19820116,
        "Al": -0.31455471,
        "As": -1.70125462,
        "Au": -0.18494148,
        "B": -0.09182149,
        "Ba": -0.03101409,
        "Be": -0.03829264,
        "Bi": -1.32456394,
        "C": -0.15573804,
        "Ca": -0.00669804,
        "Cd": -0.01269252,
        "Cr": -5.43535568,
        "Cs": -0.13345046,
        "Cu": -0.24231333,
        "Ga": -0.27760085,
        "Gd": -0.35543567,
        "Ge": -0.77067288,
        "In": -0.22759447,
        "K": -0.15885132,
        "La": -0.63873053,
        "Li": -0.29780591,  # Li_sv, 800eV
        "Mg": -0.00040000,
        "Na": -0.21928380,
        "P": -1.88664411,
        "Pb": -0.58498619,
        "Rb": -0.14189970,
        "Sb": -1.43005001,
        "Sc": -1.98188993,
        "Si": -0.87162900,
        "Sn": -0.64316709,
        "Sr": -0.02805273,
        "Te": -0.41476686,
        "Eu": 6.9898249e-07,
        "Y": -2.26275664,
    }
    return energies.get(element, False)
